/*
             LUFA Library
     Copyright (C) Dean Camera, 2017.

  dean [at] fourwalledcubicle [dot] com
           www.lufa-lib.org
*/

/*
  Copyright 2017  Dean Camera (dean [at] fourwalledcubicle [dot] com)

  Permission to use, copy, modify, distribute, and sell this
  software and its documentation for any purpose is hereby granted
  without fee, provided that the above copyright notice appear in
  all copies and that both that the copyright notice and this
  permission notice and warranty disclaimer appear in supporting
  documentation, and that the name of the author not be used in
  advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.

  The author disclaims all warranties with regard to this
  software, including all implied warranties of merchantability
  and fitness.  In no event shall the author be liable for any
  special, indirect or consequential damages or any damages
  whatsoever resulting from loss of use, data or profits, whether
  in an action of contract, negligence or other tortious action,
  arising out of or in connection with the use or performance of
  this software.
*/

/** \file
 *  \brief Board specific joystick driver header for the Fletchtronics BUMBLEB.
 *  \copydetails Group_Joystick_BUMBLEB
 *
 *  \note This file should not be included directly. It is automatically included as needed by the joystick driver
 *        dispatch header located in LUFA/Drivers/Board/Joystick.h.
 */

/** \ingroup Group_Joystick
 *  \defgroup Group_Joystick_BUMBLEB BUMBLEB
 *  \brief Board specific joystick driver header for the Fletchtronics BUMBLEB.
 *
 *  Board specific joystick driver header for the Fletchtronics BUMBLEB (http://fletchtronics.net/bumble-b). The BUMBLEB
 *  third-party board does not include any on-board peripherals, but does have an officially recommended external peripheral
 *  layout for buttons, LEDs and a Joystick.
 *
 *  <table>
 *    <tr><th>Left Port Pin</th><th>Up Port Pin</th><th>Right Port Pin</th><th>Down Port Pin</th><th>Press Port Pin</th></tr>
 *    <tr><td>PORTD.2</td><td>PORTD.3</td><td>PORTD.0</td><td>PORTD.1</td><td>PORTD.4</td></tr>
 *  </table>
 *
 *  @{
 */
#include <stdint.h>
#include <avr/io.h>
#ifndef __JOYSTICK_PINGUI_H__
#define __JOYSTICK_PINGUI_H__


	/* Includes: */
		#include "../../../../Common/Common.h"

	/* Enable C linkage for C++ Compilers: */
		#if defined(__cplusplus)
			extern "C" {
		#endif

	/* Preprocessor Checks: */
		#if !defined(__INCLUDE_FROM_JOYSTICK_H)
			#error Do not include this file directly. Include LUFA/Drivers/Board/Joystick.h instead.
		#endif

	/* Private Interface - For use in library only: */
	#if !defined(__DOXYGEN__)
		/* Macros: */
			#define JOY_MASK                 ((1 << 0) | (1 << 1) | (1 << 2) | (1 << 3) )       // (1 << 4))
	#endif

	/* Public Interface - May be used in end-application: */
		/* Macros: */
			/** Mask for the joystick being pushed in the left direction. */
			//#define JOY_V                 (1 << 2)

			/** Mask for the joystick being pushed in the upward direction. */
			//#define JOY_H                    (1 << 3)

			#define joy_X_ADC 6 //pour utilisrr l'adc par rapport aux 2 axes
			#define joy_Y_ADC 7
//			** Mask for the joystick being pushed in the right direction. 
//			#define JOY_RIGHT                 (1 << 0)
//
//			/** Mask for the joystick being pushed in the downward direction. 
//			#define JOY_DOWN                  (1 << 1)
//
		//	/** Mask for the joystick being pushed inward. 
		//	#define JOY_PRESS                 (1 << 4)
			
		/* Inline Functions: */
//these are the functions coming from the examples we got on Mr REDON website


	void adc_init(unsigned char mux)
	{
		ADCSRA = (1<<ADPS2) | (1<<ADPS1) | (1<<ADPS0);		// Maximum resolution, take some time
		ADCSRA |= (1<<ADEN);					// Enable ADC
		ADCSRB = (((mux&0x20)==0?0:1)<<MUX5);			// Line to use
		ADMUX  = mux&0x1f;
		ADMUX  |= (0<<REFS1) | (1<<REFS0);			// Reference to AVCC
		ADMUX  |= (1<<ADLAR);					// Left adjusted, it is sufficient to read ADCH
	}

	int adc_read(void)
	{
		ADCSRA |= (1<<ADSC);		// Start conversion
		while(ADCSRA & (1<<ADSC));
		return ADCH;
	}




		#if !defined(__DOXYGEN__)
			static inline void Joystick_Init(void)
			{
				DDRD  &= ~JOY_MASK;
				PORTD |=  JOY_MASK;
			}

			static inline void Joystick_Disable(void)
			{
				DDRD  &= ~JOY_MASK;
				PORTD &= ~JOY_MASK;
			}
			



			static inline uint8_t Joystick_GetStatus(void) ATTR_WARN_UNUSED_RESULT;
			static inline uint8_t Joystick_GetStatus(void)
			{
				adc_init(joy_X_ADC);
				uint8_t Xquatrebits = adc_read();
				Xquatrebits&=0xF0; //pour les quatres bits de poids fort pour axe X
				adc_init(joy_Y_ADC);
				uint8_t Yquatrebits = adc_read();
				Yquatrebits&=0xF0;
				Yquatrebits=Yquatrebits>>4; //pour les quatres bits de poids faible pour axe Y, on place en fort et on decale de 4 bits into le poids faible
				return (uint8_t)(Xquatrebits|Yquatrebits);
			}
		#endif

	/* Disable C linkage for C++ Compilers: */
		#if defined(__cplusplus)
			}
		#endif

#endif

/** @} */

